@@ -12,9 +12,8 @@ spmd.send.default <- function(x,
   ### TODO: implement array/matrix as the way done in allreduce.
   xx <- serialize(x, NULL)    ### Serialize everything who calls default.
   if(check.type){
-    ct <- c(.pbd_env$SPMD.DT$raw.object, length(xx))
-    .Call("spmd_send_integer", ct, as.integer(rank.dest),
-          as.integer(tag), as.integer(comm), PACKAGE = "pbdMPI")
+    spmd.check.type.send(.pbd_env$SPMD.DT$raw.object, length(xx),
+                         rank.dest = rank.dest, tag = tag, comm = comm)
   }
   .Call("spmd_send_raw", xx, as.integer(rank.dest), as.integer(tag),
         as.integer(comm), PACKAGE = "pbdMPI")
@@ -22,15 +21,25 @@ spmd.send.default <- function(x,
 } # End of spmd.send.default().
 
 
+### For handshaking with spmd.check.type.recv(). 
+spmd.check.type.send <- function(obj.type, obj.length,
+    rank.dest = .pbd_env$SPMD.CT$rank.dest, tag = .pbd_env$SPMD.CT$tag,
+    comm = .pbd_env$SPMD.CT$comm){
+  ct <- as.double(c(obj.type, obj.length))
+  .Call("spmd_send_double", ct, as.integer(rank.dest),
+        as.integer(tag), as.integer(comm), PACKAGE = "pbdMPI")
+  invisible()
+} # End of spmd.check.type.send().
+
+
 ### For send.
 spmd.send.integer <- function(x,
     rank.dest = .pbd_env$SPMD.CT$rank.dest, tag = .pbd_env$SPMD.CT$tag,
     comm = .pbd_env$SPMD.CT$comm,
     check.type = .pbd_env$SPMD.CT$check.type){
   if(check.type){
-    ct <- c(.pbd_env$SPMD.DT$integer, length(x))
-    .Call("spmd_send_integer", ct, as.integer(rank.dest),
-          as.integer(tag), as.integer(comm), PACKAGE = "pbdMPI")
+    spmd.check.type.send(.pbd_env$SPMD.DT$integer, length(x),
+                         rank.dest = rank.dest, tag = tag, comm = comm)
   }
   .Call("spmd_send_integer", x, as.integer(rank.dest), as.integer(tag),
         as.integer(comm), PACKAGE = "pbdMPI")
@@ -42,9 +51,8 @@ spmd.send.double <- function(x,
     comm = .pbd_env$SPMD.CT$comm,
     check.type = .pbd_env$SPMD.CT$check.type){
   if(check.type){
-    ct <- c(.pbd_env$SPMD.DT$double, length(x))
-    .Call("spmd_send_integer", ct, as.integer(rank.dest),
-          as.integer(tag), as.integer(comm), PACKAGE = "pbdMPI")
+    spmd.check.type.send(.pbd_env$SPMD.DT$double, length(x),
+                         rank.dest = rank.dest, tag = tag, comm = comm)
   }
   .Call("spmd_send_double", x, as.integer(rank.dest), as.integer(tag),
         as.integer(comm), PACKAGE = "pbdMPI")
@@ -56,9 +64,8 @@ spmd.send.raw <- function(x,
     comm = .pbd_env$SPMD.CT$comm,
     check.type = .pbd_env$SPMD.CT$check.type){
   if(check.type){
-    ct <- c(.pbd_env$SPMD.DT$raw, length(x))
-    .Call("spmd_send_integer", ct, as.integer(rank.dest),
-          as.integer(tag), as.integer(comm), PACKAGE = "pbdMPI")
+    spmd.check.type.send(.pbd_env$SPMD.DT$raw, length(x),
+                         rank.dest = rank.dest, tag = tag, comm = comm)
   }
   .Call("spmd_send_raw", x, as.integer(rank.dest), as.integer(tag),
         as.integer(comm), PACKAGE = "pbdMPI")
@@ -93,4 +100,3 @@ setMethod(
   signature = signature(x = "raw"),
   definition = spmd.send.raw
 )
-
